From d141ac016ad587b052886b17b42c8c4dc77aba98 Mon Sep 17 00:00:00 2001
From: Andreas Sturmlechner <asturm@gentoo.org>
Date: Sat, 20 Feb 2021 22:53:46 +0100
Subject: [PATCH] Use CTest module provided BUILD_TESTING (default: ON)

Signed-off-by: Andreas Sturmlechner <asturm@gentoo.org>
---
 CMakeLists.txt | 32 +++++++++++++++++++-------------
 1 file changed, 19 insertions(+), 13 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index 5c42816..5d52baf 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -11,9 +11,10 @@ set(QUAZIP_LIB_SOVERSION 1.0.0)
 option(BUILD_SHARED_LIBS "" ON)
 option(QUAZIP_INSTALL "" ON)
 option(QUAZIP_USE_QT_ZLIB "" OFF)
-option(QUAZIP_ENABLE_TESTS "Build QuaZip tests" OFF)
 set(QUAZIP_QT_MAJOR_VERSION 5 CACHE STRING "Qt version to use (4 or 5), defaults to 5")
 
+include(CTest)
+
 if(NOT CMAKE_BUILD_TYPE)
 	set(CMAKE_BUILD_TYPE RELEASE)
 endif()
@@ -30,23 +31,29 @@ set(QUAZIP_DIR_NAME QuaZip-Qt${QUAZIP_QT_MAJOR_VERSION}-${QUAZIP_LIB_VERSION})
 set(QUAZIP_PACKAGE_NAME QuaZip-Qt${QUAZIP_QT_MAJOR_VERSION})
 
 if(QUAZIP_QT_MAJOR_VERSION EQUAL 6)
-	find_package(Qt6 REQUIRED COMPONENTS Core Core5Compat
-                         OPTIONAL_COMPONENTS Network Test)
+	find_package(Qt6 REQUIRED COMPONENTS Core Core5Compat)
 	set(QUAZIP_LIB_LIBRARIES Qt6::Core Qt6::Core5Compat)
-	set(QUAZIP_TEST_QT_LIBRARIES Qt6::Core Qt6::Core5Compat Qt6::Network Qt6::Test)
 	set(QUAZIP_PKGCONFIG_REQUIRES Qt6Core)
+	if (BUILD_TESTING)
+		find_package(Qt6 REQUIRED COMPONENTS Network Test)
+		set(QUAZIP_TEST_QT_LIBRARIES Qt6::Core Qt6::Core5Compat Qt6::Network Qt6::Test)
+	endif()
 elseif(QUAZIP_QT_MAJOR_VERSION EQUAL 5)
-	find_package(Qt5 REQUIRED COMPONENTS Core
-                         OPTIONAL_COMPONENTS Network Test)
+	find_package(Qt5 REQUIRED COMPONENTS Core)
 	set(QUAZIP_LIB_LIBRARIES Qt5::Core)
-	set(QUAZIP_TEST_QT_LIBRARIES Qt5::Core Qt5::Network Qt5::Test)
-	set(QUAZIP_PKGCONFIG_REQUIRES Qt5Core)
+	set(QUAZIP_PKGCONFIG_REQUIRES "zlib, Qt5Core")
+	if (BUILD_TESTING)
+		find_package(Qt5 REQUIRED COMPONENTS Network Test)
+		set(QUAZIP_TEST_QT_LIBRARIES Qt5::Core Qt5::Network Qt5::Test)
+	endif()
 elseif(QUAZIP_QT_MAJOR_VERSION EQUAL 4)
-	find_package(Qt4 4.5.0 REQUIRED COMPONENTS QtCore
-                           OPTIONAL_COMPONENTS QtNetwork QtTest)
+	find_package(Qt4 4.5.0 REQUIRED COMPONENTS QtCore)
 	set(QUAZIP_LIB_LIBRARIES Qt4::QtCore)
-	set(QUAZIP_TEST_QT_LIBRARIES Qt4::QtCore Qt4::QtNetwork Qt4::QtTest)
 	set(QUAZIP_PKGCONFIG_REQUIRES QtCore)
+	if (BUILD_TESTING)
+		find_package(Qt4 REQUIRED COMPONENTS Network Test)
+		set(QUAZIP_TEST_QT_LIBRARIES Qt4::QtCore Qt4::QtNetwork Qt4::QtTest)
+	endif()
 else()
 	message(FATAL_ERROR "Qt version ${QUAZIP_QT_MAJOR_VERSION} is not supported")
 endif()
@@ -67,8 +74,7 @@ endif()
 
 add_subdirectory(quazip)
 
-if(QUAZIP_ENABLE_TESTS)
+if(BUILD_TESTING)
     message(STATUS "Building QuaZip tests")
-    enable_testing()
     add_subdirectory(qztest)
 endif()
-- 
2.34.1

